@@ -3,10 +3,9 @@
 
 """Some functions related to file operations."""
 import os
+from pathlib import Path
 from user_tools import util_time
 from user_tools import util_check
-import user_tools.util_time as ut
-import user_tools.util_check as uc
 
 SIZE_UNIT = {
     "GB": float(1024*1024*1024),
@@ -15,7 +14,7 @@ SIZE_UNIT = {
 }
 
 
-def write_file(file_path, msg, mode="a", encoding="UTF-8"):
+def write_file(file_path: str, msg: str, mode: str = "a", encoding: str = "UTF-8") -> None:
     """Write the contents of msg to file_path.
 
     :param file_path(str): File to be written.\n
@@ -43,7 +42,7 @@ def write_file(file_path, msg, mode="a", encoding="UTF-8"):
             f.write(msg)
 
 
-def read_file(file_path, mode="r", encoding="UTF-8"):
+def read_file(file_path: str, mode: str = "r", encoding: str = "UTF-8") -> str:
     """Return the content of file_path.
 
     :param file_path(str): File to be read.\n
@@ -72,16 +71,16 @@ def read_file(file_path, mode="r", encoding="UTF-8"):
     return msg
 
 
-def get_file_suffix(filename):
+def get_file_suffix(filename: str) -> str:
     """Return the suffix of filename.
 
     :param filename(str): File name to get the suffix.\n
     :return(str): The suffix of filename."""
 
-    return os.path.splitext(filename)[1]
+    return Path(filename).suffix
 
 
-def get_file_size(file_path, size_unit="MB"):
+def get_file_size(file_path: str, size_unit: str = "MB") -> float:
     """Return the size of file_path.
 
     :param file_path(str): File path to get file size.\n
@@ -94,19 +93,20 @@ def get_file_size(file_path, size_unit="MB"):
     :return(float): The size of file_path. Exact to two digits after the decimal point.
         A file size of -1 means the file does not exist."""
 
+    size_type = 0.0
     if size_unit in SIZE_UNIT:
-        size_unit = SIZE_UNIT[size_unit]
+        size_type = SIZE_UNIT[size_unit]
     else:
-        size_unit = SIZE_UNIT["MB"]
-    file_size = -1
+        size_type = SIZE_UNIT["MB"]
+    file_size = -1.0
     if util_check.is_exist(file_path):
         tmp_size = os.path.getsize(file_path)
-        size = tmp_size / size_unit
+        size = tmp_size / size_type
         file_size = round(size, 2)
     return file_size
 
 
-def get_file_ctime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
+def get_file_ctime(file_path: str, format_str: str = '%Y-%m-%d %H:%M:%S') -> str:
     """Get and format file creation time and return.
 
     :param file_path(str): File path to get creation time.\n
@@ -137,7 +137,7 @@ def get_file_ctime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
     return ctime
 
 
-def get_file_atime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
+def get_file_atime(file_path: str, format_str: str = '%Y-%m-%d %H:%M:%S') -> str:
     """Get and format file access time and return.
 
     :param file_path(str): File path to get access time.\n
@@ -168,7 +168,7 @@ def get_file_atime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
     return atime
 
 
-def get_file_mtime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
+def get_file_mtime(file_path: str, format_str: str = '%Y-%m-%d %H:%M:%S') -> str:
     """Get and format file modification time and return.
 
     :param file_path(str): File path to get modification time.\n
