@@ -2,12 +2,11 @@
 # -*- coding: UTF-8 -*-
 
 """Some functions related to hash operations."""
-import os
 import hashlib
 from user_tools import util_check
 
 
-def get_str_md5(string):
+def get_str_md5(string: str) -> str:
     """Returns the MD5 value of a string.
 
     :param string(str): String to get the MD5 value.\n
@@ -16,12 +15,12 @@ def get_str_md5(string):
 
     md5name = ""
     if not string:
-        tmp_md5 = hashlib.md5(string)
+        tmp_md5 = hashlib.md5(bytes(string, encoding="UTF-8"))
         md5name = tmp_md5.hexdigest().upper()
     return md5name
 
 
-def get_file_md5(file_path):
+def get_file_md5(file_path: str) -> str:
     """Returns the MD5 value of a file.
 
     :param file_path(str): File path to get MD5 value.\n
