@@ -3,7 +3,7 @@
 
 """Some functions related to image operations."""
 import string
-from os.path import basename
+from pathlib import Path
 from user_tools import util_hashlib
 from user_tools import util_check
 from user_tools import util_file
@@ -13,7 +13,7 @@ UPPER_LETTER = string.ascii_uppercase
 IMG_SUFFIX = [".bmp", ".gif", ".jpg", ".jpeg", ".png", ".psd", ".webp", ".ico"]
 
 
-def rename_img(img_name):
+def rename_img(img_name: str) -> str:
     """Rename the picture and return the renamed name.\n
         The picture name is changed to %Y%m%d%H%M%S_short_bit_md5.
         Short_bit_md5 is the first five digits of the image file md5.
@@ -42,7 +42,7 @@ def rename_img(img_name):
                     real_name += str(UPPER_LETTER.find(i))
             real_name += suffix
         else:
-            str1 = f"util_img [note]: {basename(img_name)} "
+            str1 = f"util_img [note]: {Path(img_name).parent} "
             str2 = f"file type not in {IMG_SUFFIX}"
             print(str1 + str2)
     return real_name
