@@ -7,7 +7,7 @@ import time
 NOW_TIME = time.time()
 
 
-def format_time(timestamp=NOW_TIME, format_str='%Y-%m-%d %H:%M:%S'):
+def format_time(timestamp: float = NOW_TIME, format_str: str = '%Y-%m-%d %H:%M:%S') -> str:
     """Format timestamp returns format_str time.
 
     :param timestamp(float): The timestamp to be formatted.
